#[non_exhaustive]pub enum FastIcaError {
NotEnoughSamples,
InvalidValue(String),
SvdDecomposition,
InvalidTolerance(f32),
LinalgError(LinalgError),
LinfaError(Error),
}Expand description
An error when modeling FastICA algorithm
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotEnoughSamples
When there are no samples in the provided dataset
InvalidValue(String)
When any of the hyperparameters are set the wrong value
SvdDecomposition
If we fail to compute any components of the SVD decomposition due to an Ill-Conditioned matrix
InvalidTolerance(f32)
LinalgError(LinalgError)
Errors encountered during linear algebra operations
LinfaError(Error)