pub struct FastIcaParams<F: Float>(/* private fields */);Implementations
Sourceimpl<F: Float> FastIcaParams<F>
impl<F: Float> FastIcaParams<F>
Sourcepub fn ncomponents(self, ncomponents: usize) -> Self
pub fn ncomponents(self, ncomponents: usize) -> Self
Set the number of components to use, if not set all are used
Sourcepub fn gfunc(self, gfunc: GFunc) -> Self
pub fn gfunc(self, gfunc: GFunc) -> Self
G function used in the approximation to neg-entropy, refer GFunc
Sourcepub fn random_state(self, random_state: usize) -> Self
pub fn random_state(self, random_state: usize) -> Self
Set seed for random number generator for reproducible results.